@@ -18,10 +18,15 @@
  *
  */
 
+#if !defined (__EV_EVINCE_DOCUMENT_H_INSIDE__) && !defined (EVINCE_COMPILATION)
+#error "Only <evince-document.h> can be included directly."
+#endif
+
 #ifndef EV_DOCUMENT_FACTORY_H
 #define EV_DOCUMENT_FACTORY_H
 
 #include <gtk/gtk.h>
+
 #include "ev-document.h"
 
 G_BEGIN_DECLS
