@@ -17,11 +17,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#if !defined (__EV_EVINCE_DOCUMENT_H_INSIDE__) && !defined (EVINCE_COMPILATION)
+#error "Only <evince-document.h> can be included directly."
+#endif
+
 #ifndef __EV_IMAGE_H__
 #define __EV_IMAGE_H__
 
 #include <glib-object.h>
-#include <gdk/gdkpixbuf.h>
+#include <gdk/gdk.h>
 
 G_BEGIN_DECLS
 
