@@ -27,17 +27,19 @@
  *
  */
 
-#include "ev-properties-view.h"
-#include "ev-backends-manager.h"
-#include "ev-document-factory.h"
-
 #include <config.h>
+
 #include <string.h>
+
 #include <glib/gi18n-lib.h>
-#include <gtk/gtklabel.h>
+#include <gtk/gtk.h>
+
 #include <libnautilus-extension/nautilus-extension-types.h>
 #include <libnautilus-extension/nautilus-property-page-provider.h>
 
+#include <evince-document.h>
+#include "ev-properties-view.h"
+
 static GType epp_type = 0;
 static void property_page_provider_iface_init
 	(NautilusPropertyPageProviderIface *iface);
@@ -109,7 +111,7 @@ ev_properties_get_pages (NautilusPropertyPageProvider *provider,
 		goto end;
 
 	label = gtk_label_new (_("Document"));
-	page = ev_properties_view_new ();
+	page = ev_properties_view_new (uri);
 	ev_properties_view_set_info (EV_PROPERTIES_VIEW (page),
 				     ev_document_get_info (document));
 	gtk_widget_show (page);
@@ -135,13 +137,13 @@ nautilus_module_initialize (GTypeModule *module)
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
-	ev_backends_manager_init ();
+        ev_init ();
 }
 
 void
 nautilus_module_shutdown (void)
 {
-	ev_backends_manager_shutdown ();
+        ev_shutdown ();
 }
 
 void
@@ -154,4 +156,3 @@ nautilus_module_list_types (const GType **types,
 	*types = type_list;
 	*num_types = G_N_ELEMENTS (type_list);
 }
-
