@@ -23,9 +23,8 @@
 #ifndef EV_WINDOW_H
 #define EV_WINDOW_H
 
-#include <glib-object.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkscrolledwindow.h>
+#include <glib.h>
+#include <gtk/gtk.h>
 
 #include "ev-link.h"
 #include "ev-page-cache.h"
